@@ -377,7 +377,7 @@ class Zymkey(object):
    #    VerificationError will be raised, unless this is set to False
    #  @param pubkey_slot The key slot to use to verify the signature against. Defaults to the first key slot.
    #  @returns True for a good verification or False for a bad verification when raise_exception is False
-   def verify(self, src, sig, raise_exception=True, pubkey_slot=None, foreign=False):
+   def verify(self, src, sig, raise_exception=True, pubkey_slot=0, foreign=False):
       sha256 = hashlib.sha256()
       sha256.update(src.encode('utf-8'))
 
@@ -394,7 +394,7 @@ class Zymkey(object):
    #    VerificationError will be raised, unless this is set to False
    #  @param pubkey_slot The key slot to use to verify the signature against. Defaults to the first key slot.
    #  @returns True for a good verification or False for a bad verification when raise_exception is False
-   def verify_digest(self, sha256, sig, raise_exception=True, pubkey_slot=None, foreign=False):
+   def verify_digest(self, sha256, sig, raise_exception=True, pubkey_slot=0, foreign=False):
         digest_bytes = bytearray(sha256.digest())
 
         src_sz = len(digest_bytes)
